import { createSlice, type PayloadAction } from "@reduxjs/toolkit";
import type { Account, MeAccount } from "$lib/api/entities/account";

const accountsSlice = createSlice({
	name: "accounts",
	initialState: {
		currentAccount: JSON.parse(
			document.getElementById("accountData")!.innerHTML,
		) as MeAccount,
		accounts: {},
		usernames: {},
	} as {
		currentAccount: MeAccount;
		accounts: Record<string, Account>;
		usernames: Record<string, string>;
	},
	reducers: {
		setAccount(state, action: PayloadAction<Account>) {
			state.usernames[action.payload.username] = action.payload.id; // TODO: change to acct-equivalent field
			state.accounts[action.payload.id] = action.payload;
		},
		removeAccount(state, action: PayloadAction<string>) {
			delete state.accounts[action.payload];
		},
		setCurrentAccount(state, action: PayloadAction<MeAccount>) {
			state.currentAccount = action.payload;
			state.accounts[action.payload.id] = action.payload;
		},
	},
});

export const accounts = accountsSlice.reducer;
export const { setAccount, removeAccount } = accountsSlice.actions;
